Date: 2023-07-17
Package: chem16S
Version: 1.0.0
Title: Chemical Metrics of Community Reference Proteomes
Authors@R: c(
    person("Jeffrey", "Dick", , "j3ffdick@gmail.com", role = c("aut", "cre"),
      comment = c(ORCID = "0000-0002-0687-5890"))
    )
Author: Jeffrey Dick [aut, cre] (<https://orcid.org/0000-0002-0687-5890>)
Maintainer: Jeffrey Dick <j3ffdick@gmail.com>
Depends: R (>= 3.5.0)
Imports: plyr, ggplot2, rlang, reshape2, phyloseq
Suggests: tinytest, knitr, patchwork, ggpmisc, rmarkdown
Description: Combines taxonomic classifications of high-throughput 16S rRNA
  gene sequences with reference proteomes of archaeal and bacterial taxa to
  generate amino acid compositions of community reference proteomes. Calculates
  chemical metrics including carbon oxidation state ('Zc'), stoichiometric
  oxidation and hydration state ('nO2' and 'nH2O'), H/C, N/C, O/C, and S/C
  ratios, grand average of hydropathicity ('GRAVY'), isoelectric point ('pI'),
  protein length, and average molecular weight of amino acid residues. Uses
  precomputed reference proteomes for archaea and bacteria derived from the
  Genome Taxonomy Database ('GTDB'). Also includes reference proteomes derived
  from the NCBI Reference Sequence ('RefSeq') database and manual mapping from
  the 'RDP Classifier' training set to 'RefSeq' taxonomy as described by Dick and
  Tan (2023) <doi:10.1007/s00248-022-01988-9>. Processes taxonomic
  classifications in 'RDP Classifier' format or OTU tables in 'phyloseq-class'
  objects from the Bioconductor package 'phyloseq'.
Encoding: UTF-8
License: GPL-3
VignetteBuilder: knitr
URL: https://github.com/jedick/chem16S,
        https://doi.org/10.5281/zenodo.6793059
NeedsCompilation: no
Packaged: 2023-07-17 02:25:55 UTC; jedick
Repository: CRAN
Date/Publication: 2023-07-17 17:10:02 UTC
Built: R 4.2.0; ; 2023-07-17 18:22:51 UTC; unix
