# Exports for chem16S package
export(
  "read_RDP",
  "map_taxa",
  "get_metrics",
  "get_metadata",
  "plot_metrics",
  "add_hull",
  # Integration with phyloseq 20230608
  "ps_taxacounts", "ps_metrics", "plot_ps_metrics",
  # 20230617
  "plot_ps_metrics2",
  # 20230704
  "calc_metrics", "chemlab"
)

importFrom("stats", "aggregate", "na.omit")
importFrom("utils", "read.csv", "read.table", "tail", "modifyList")
importFrom("grDevices", "chull", "col2rgb", "rgb")
importFrom("graphics", "box", "lines", "par", "polygon")

# Integration with phyloseq 20230608
# Moved phyloseq to Suggests 20230619
# importFrom("phyloseq", "tax_table", "taxa_sums", "otu_table", "taxa_are_rows", "sample_data", "sample_names")
importFrom("plyr", "is.discrete")
importFrom("ggplot2", "aes", "ggplot", "geom_point", "theme", "element_text", "xlab", "ylab",
  "facet_wrap", "ggtitle", "labeller", "label_parsed")
importFrom("rlang", ".data")
importFrom("reshape2", "melt")
