# Run R scripts to produce output files in this order:
# 1. taxonomy.R  --> taxonomy.csv (hosted in https://github.com/jedick/JMDplots because of its size)
# 2. genome_AA.R --> genome_AA.csv (hosted in https://github.com/jedick/JMDplots because of its size)
# 3. taxon_AA.R  --> taxon_AA.csv

[20240706] NOTE for GTDB 220.0:
Updated spellings and validly published names identified post-curation cycle
(see GTDB's RELEASE_NOTES.txt) have been applied here.
